@@ -1,6 +1,9 @@
-import multiprocessing
-import tqdm
+import asyncio
 import functools
+import multiprocessing
+
+import tqdm
+import tqdm.asyncio
 
 
 class Iterator:
@@ -70,6 +73,7 @@ class SingleProcess(Iterator):
     SingleProcess
 
     """
+
     def __init__(self, process, total=None, **kwargs):
         super().__init__(process, total)
 
@@ -92,7 +96,8 @@ class MultiProcess(Iterator):
     MultiProcess
 
     """
-    def __init__(self, process, total=None, nprocs=multiprocessing.cpu_count()):
+
+    def __init__(self, process, total=None, nprocs=multiprocessing.cpu_count(), **kwargs):
         super().__init__(process, total)
 
         self.nprocs = nprocs if nprocs > 0 else multiprocessing.cpu_count()
@@ -111,3 +116,36 @@ class MultiProcess(Iterator):
             ret_list = list(tqdm.tqdm(p.imap(self, zip(self.dynamic_args, self.dynamic_kwargs)),
                                       total=self.total, desc=self.func.__name__))
         return ret_list
+
+
+class AsyncProcess(Iterator):
+    """
+    AsyncProcess
+
+    """
+
+    def __init__(self, process, total=None, **kwargs):
+        super().__init__(process, total)
+
+        self.ret_list = None
+
+    def __call__(self, args):
+        return self.partial_func(*args[0], **args[1])
+
+    async def main(self, loop):
+        tasks = [loop.create_task(self(args)) for args in zip(self.dynamic_args, self.dynamic_kwargs)]
+        for f in tqdm.asyncio.tqdm.as_completed(tasks, total=self.total, desc=self.func.__name__):
+            await f
+        self.ret_list = [task.result() for task in tasks]
+
+    def run(self, *args, **kwargs):
+        """run - Please ensure that static arguments precede dynamic arguments"""
+
+        # parse
+        self.parse(*args, **kwargs)
+
+        # run
+        loop = asyncio.new_event_loop()
+        asyncio.set_event_loop(loop)
+        loop.run_until_complete(self.main(loop))
+        return self.ret_list
