@@ -5,7 +5,9 @@ import glob
 
 
 def image2pdf(image_file_list, pdf_file):
-    assert len(image_file_list), 'There is no image'
+    if len(image_file_list) == 0:
+        return
+
     doc = fitz.open()
     for image_file in image_file_list:
         imgdoc = fitz.open(image_file)
@@ -18,21 +20,20 @@ def image2pdf(image_file_list, pdf_file):
 
 def main():
     parser = argparse.ArgumentParser()
-    parser.add_argument('-i', '--input', type=str, default='.', help='input image file or path of image files')
+    parser.add_argument('-i', '--input', type=str, default='.', help='input image file or input path')
     parser.add_argument('-o', '--output', type=str, help='output pdf file')
-    parser.add_argument('-p', '--postfix', type=str, default='png', help='postfix of image filename (valid only if '
-                                                                         'input is a path)')
+    parser.add_argument('-p', '--postfix', type=str, default='png', help='postfix of image filename valid only if '
+                                                                         '\'input\' is a path)')
     opts = parser.parse_args()
+    print(opts)
 
     if os.path.isdir(opts.input):
-        opts.output = os.path.abspath(opts.input) + '.pdf' if opts.output is None else opts.output
         image_file_list = sorted(glob.glob(os.path.join(opts.input, f'*.{opts.postfix}')))
+        pdf_file = os.path.abspath(opts.input) + '.pdf' if opts.output is None else opts.output
     else:
-        opts.output = os.path.splitext(opts.input)[0] + '.pdf' if opts.output is None else opts.output
         image_file_list = [opts.input]
+        pdf_file = os.path.splitext(opts.input)[0] + '.pdf' if opts.output is None else opts.output
 
-    print(opts)
-    pdf_file = opts.output
     image2pdf(image_file_list, pdf_file)
 
 
