@@ -1,4 +1,5 @@
-from src.lh_tool.Iterator import SingleProcess, MultiProcess
+import asyncio
+from src.lh_tool.Iterator import SingleProcess, MultiProcess, AsyncProcess
 
 
 def process(a, b, opt='+'):
@@ -8,6 +9,14 @@ def process(a, b, opt='+'):
         return a - b
 
 
+async def async_process(a, b, opt='+'):
+    await asyncio.sleep(1)
+    if opt == '+':
+        return a + b
+    else:
+        return a - b
+
+
 def test_iterator():
     print('Test lh_tool.MultiProcess')
     a = [i for i in range(10)]
@@ -18,6 +27,9 @@ def test_iterator():
     result_list = MultiProcess(process, nprocs=1).run(a=a, b=b, opt='+')
     print(result_list)
 
+    result_list = AsyncProcess(async_process).run(a=a, b=b, opt='+')
+    print(result_list)
+
 
 if __name__ == '__main__':
     test_iterator()
